ae-dir-pproc
============

Python module package for processes running on a Æ-DIR provider.

This package is automatically installed by ansible role
[ansible-ae-dir-server](https://code.stroeder.com/AE-DIR/ansible-ae-dir-server)
and is not useful for anything else.
